@@ -35,6 +35,7 @@ Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 #include <yaz/icu.h>
 #endif
 #include <yaz/log.h>
+#include <yaz/snprintf.h>
 #include <yaz/options.h>
 #include <idzebra/version.h>
 #include <idzebra/api.h>
@@ -71,7 +72,7 @@ int main(int argc, char **argv)
 
 #ifdef WIN32
 #else
-    sprintf(nbuf, "%.40s(%ld)", *argv, (long) getpid());
+    yaz_snprintf(nbuf, sizeof(nbuf), "%s(%ld)", *argv, (long) getpid());
     yaz_log_init_prefix(nbuf);
 #endif
     prog = *argv;
@@ -248,7 +249,7 @@ int main(int argc, char **argv)
             zebra_get_version(version_str, sys_str);
 
             printf("Zebra %s\n", version_str);
-            printf("(C) 1994-2022, Index Data\n");
+            printf("(C) 1994-2023, Index Data\n");
             printf("Zebra is free software, covered by the GNU General Public License, and you are\n");
             printf("welcome to change it and/or distribute copies of it under certain conditions.\n");
             printf("SHA1 ID: %s\n", sys_str);
