@@ -38,19 +38,19 @@ static void tst(int argc, char **argv)
     zh = zebra_open(zs, 0);
     YAZ_CHECK(zh);
 
-    YAZ_CHECK(zebra_begin_trans (zh, 1) == ZEBRA_OK);
+    YAZ_CHECK(zebra_begin_trans(zh, 1) == ZEBRA_OK);
 
     for (i = 0; i<no_db; i++)
     {
         char dbstr[20];
         char rec_buf[100];
 
-        sprintf(dbstr, "%d", i);
+        yaz_snprintf(dbstr, sizeof(dbstr), "%d", i);
         YAZ_CHECK(zebra_select_database(zh, dbstr) == ZEBRA_OK);
 
-        sprintf(rec_buf, "<gils><title>title %d</title></gils>\n", i);
+        yaz_snprintf(rec_buf, sizeof(rec_buf),
+            "<gils><title>title %d</title></gils>\n", i);
         zebra_add_record (zh, rec_buf, strlen(rec_buf));
-
     }
     YAZ_CHECK(zebra_end_trans(zh) == ZEBRA_OK);
 
@@ -61,10 +61,10 @@ static void tst(int argc, char **argv)
     {
         char dbstr[20];
         char querystr[50];
-        sprintf(dbstr, "%d", i);
+        yaz_snprintf(dbstr, sizeof(dbstr), "%d", i);
         YAZ_CHECK(zebra_select_database(zh, dbstr) == ZEBRA_OK);
 
-        sprintf(querystr, "@attr 1=4 %d", i);
+        yaz_snprintf(querystr, sizeof(querystr), "@attr 1=4 %d", i);
         if (i == no_db)
         {
             YAZ_CHECK(tl_query_x(zh, querystr, 0, 109));
